@@ -5,7 +5,8 @@ require 'puppet/indirector/resource/puppetdb'
 
 describe Puppet::Resource::Puppetdb do
   before :each do
-    Puppet::Util::Puppetdb.stubs(:load_puppetdb_config).returns ['localhost', 0]
+    Puppet::Util::Puppetdb.stubs(:server).returns 'localhost'
+    Puppet::Util::Puppetdb.stubs(:port).returns 0
     Puppet::Resource.indirection.stubs(:terminus).returns(subject)
   end
 
@@ -28,6 +29,21 @@ describe Puppet::Resource::Puppetdb do
       search("exec").should == []
     end
 
+    it "should log a deprecation warning if one is returned from PuppetDB" do
+      response = Net::HTTPOK.new('1.1', 200, 'OK')
+      response['x-deprecation'] = "Deprecated, yo."
+
+      response.stubs(:body).returns '[]'
+
+      subject.stubs(:http_get).returns response
+
+      Puppet.expects(:deprecation_warning).with do |msg|
+        msg =~ /Deprecated, yo\./
+      end
+
+      search("exec")
+    end
+
     it "should fail it can't connect to the PuppetDB server" do
       expect { search("user") }.to raise_error(Puppet::Error, /Could not retrieve resources/)
     end
@@ -38,8 +54,7 @@ describe Puppet::Resource::Puppetdb do
           ['and',
            ['=', 'type', 'File'],
            ['=', 'exported', true],
-           ['=', ['node', 'active'], true],
-           ['not', ['=', ['node', 'name'], host]]]
+           ['not', ['=', 'certname', host]]]
       }
 
       def make_resource_hash(name, certname="localhost", exported=true)
@@ -65,7 +80,7 @@ describe Puppet::Resource::Puppetdb do
 
         Net::HTTP.any_instance.stubs(:get).with do |uri, headers|
           path, query_string = uri.split('?query=')
-          path == '/resources' and PSON.load(CGI.unescape(query_string)) == query
+          path == '/v2/resources' and PSON.load(CGI.unescape(query_string)) == query
         end.returns response
       end
 
@@ -124,7 +139,7 @@ describe Puppet::Resource::Puppetdb do
     end
 
     it "should return a not-equal query if the operator is '!='" do
-      subject.build_expression(['param','!=','value']).should == ['not', ['=',['parameter','param'],'value']]
+      subject.build_expression(['param','!=','value']).should == ['not', ['=', ['parameter','param'],'value']]
     end
 
     it "should handle title correctly" do
