@@ -60,6 +60,7 @@
   (:require [clojure.tools.logging :as log]
             [com.puppetlabs.puppetdb.scf.storage :as scf-storage]
             [com.puppetlabs.puppetdb.catalog :as cat]
+            [com.puppetlabs.puppetdb.report :as report]
             [com.puppetlabs.puppetdb.command.dlo :as dlo]
             [com.puppetlabs.mq :as mq]
             [com.puppetlabs.utils :as pl-utils]
@@ -187,10 +188,10 @@
           (number? version)
           (satisfies? JSONable payload)]
    :post [(map? %)
-          (string? (:payload %))]}
+          (:payload %)]}
   {:command command
    :version version
-   :payload (json/generate-string payload)})
+   :payload payload})
 
 (defn annotate-command
   "Annotate a command-map with a timestamp and UUID"
@@ -223,7 +224,7 @@
            body    (format "checksum=%s&payload=%s"
                            (pl-utils/utf8-string->sha1 message)
                            (url-encode message))
-           url     (format "http://%s:%s/commands" host port)]
+           url     (format "http://%s:%s/v2/commands" host port)]
        (client/post url {:body               body
                          :throw-exceptions   false
                          :content-type       :x-www-form-urlencoded
@@ -266,14 +267,13 @@
           (number? version)]
    :post [(string? %)]}
   (with-open [conn (mq/connect! mq-spec)]
-    (let [command-map (-> (assemble-command command version payload)
-                          (annotate-command))]
+    (let [command-map (annotate-command (assemble-command command version payload))]
       (mq/publish-json! conn mq-endpoint command-map)
       (get-in command-map [:annotations :id]))))
 
 ;; ## Command processing exception classes
 
-(defn fatality!
+(defn fatality
   "Create an object representing a fatal command-processing exception
 
   cause - object representing the cause of the failure
@@ -287,6 +287,13 @@
   [exception]
   (:fatal exception))
 
+(defmacro upon-error-throw-fatality
+  [& body]
+  `(try+
+     ~@body
+     (catch Throwable e#
+       (throw+ (fatality e#)))))
+
 ;; ## Command processors
 
 (defmulti process-command!
@@ -297,51 +304,49 @@
 
 ;; Catalog replacement
 
-(defmethod process-command! ["replace catalog" 1]
-  [{:keys [payload annotations]} {:keys [db]}]
-  ;; Parsing a catalog either works, or it generates a fatal exception
-  (let [catalog   (try+
-                   (cat/parse-from-json-string payload)
-                   (catch Throwable e
-                     (throw+ (fatality! e))))
-        certname  (:certname catalog)
-        id        (:id annotations)
+(defn replace-catalog*
+  [{:keys [payload annotations version]} {:keys [db]}]
+  (let [catalog (upon-error-throw-fatality (cat/parse-catalog payload version))
+        certname (:certname catalog)
+        id (:id annotations)
         timestamp (:received annotations)]
     (with-transacted-connection db
-      (when-not (scf-storage/certname-exists? certname)
-        (scf-storage/add-certname! certname))
-      (if (scf-storage/maybe-activate-node! certname timestamp)
-        ;; Only store a catalog if it's newer than the current catalog
-        (if-not (scf-storage/catalog-newer-than? certname timestamp)
-          (scf-storage/replace-catalog! catalog timestamp))))
+      (scf-storage/maybe-activate-node! certname timestamp)
+      ;; Only store a catalog if it's newer than the current catalog
+      (if-not (scf-storage/catalog-newer-than? certname timestamp)
+        (scf-storage/replace-catalog! catalog timestamp)))
     (log/info (format "[%s] [replace catalog] %s" id certname))))
 
+(defmethod process-command! ["replace catalog" 1]
+  [{:keys [version payload] :as command} options]
+  {:pre [(= version 1)]}
+  (when-not (string? payload)
+    (throw (IllegalArgumentException. "Payload for a 'replace catalog' v1 command must be a JSON string.")))
+  (replace-catalog* command options))
+
+(defmethod process-command! ["replace catalog" 2]
+  [{:keys [version] :as  command} options]
+  {:pre [(= version 2)]}
+  (replace-catalog* command options))
+
 ;; Fact replacement
 
 (defmethod process-command! ["replace facts" 1]
   [{:keys [payload annotations]} {:keys [db]}]
-  (let [{:strs [name] :as facts} (try+
-                                  (json/parse-string payload)
-                                  (catch Throwable e
-                                    (throw+ (fatality! e))))
+  (let [{:strs [name] :as facts} (upon-error-throw-fatality (json/parse-string payload))
         id                       (:id annotations)
         timestamp                (:received annotations)]
     (with-transacted-connection db
-      (when-not (scf-storage/certname-exists? name)
-        (scf-storage/add-certname! name))
-      (if (scf-storage/maybe-activate-node! name timestamp)
-        (if-not (scf-storage/facts-newer-than? name timestamp)
-          (scf-storage/replace-facts! facts timestamp))))
+      (scf-storage/maybe-activate-node! name timestamp)
+      (if-not (scf-storage/facts-newer-than? name timestamp)
+        (scf-storage/replace-facts! facts timestamp)))
     (log/info (format "[%s] [replace facts] %s" id name))))
 
 ;; Node deactivation
 
 (defmethod process-command! ["deactivate node" 1]
   [{:keys [payload annotations]} {:keys [db]}]
-  (let [certname (try+
-                  (json/parse-string payload)
-                  (catch Throwable e
-                    (throw+ (fatality! e))))
+  (let [certname (upon-error-throw-fatality (json/parse-string payload))
         id       (:id annotations)]
     (with-transacted-connection db
       (when-not (scf-storage/certname-exists? certname)
@@ -349,6 +354,21 @@
       (scf-storage/deactivate-node! certname))
     (log/info (format "[%s] [deactivate node] %s" id certname))))
 
+;; Report submission
+
+(defmethod process-command! ["store report" 1]
+  [{:keys [payload annotations]} {:keys [db]}]
+  (let [id          (:id annotations)
+        report      (upon-error-throw-fatality
+                      (report/validate! payload))
+        name        (:certname report)
+        timestamp   (:received annotations)]
+    (with-transacted-connection db
+      (scf-storage/maybe-activate-node! name timestamp)
+      (scf-storage/add-report! report timestamp))
+    (log/info (format "[%s] [store report (EXPERIMENTAL!)] puppet v%s - %s"
+                id (:puppet-version report) (:certname report)))))
+
 ;; ## MQ I/O
 ;;
 ;; The data flow through the code is as follows:
